import { HttpClient, NonNullablePaths, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { ScriptProperties, EmbedScriptOptions, EmbedScriptResponse, GetEmbeddedScriptOptions } from './index.typings.js';
export { EmbedScriptByInstanceIdRequest, EmbedScriptRequest, GetEmbeddedScriptByInstanceIdRequest, GetEmbeddedScriptRequest, GetEmbeddedScriptResponse } from './index.typings.js';

type ScriptPropertiesNonNullablePaths = `disabled`;
declare function embedScript$1(httpClient: HttpClient): EmbedScriptSignature;
interface EmbedScriptSignature {
    /**
     * Inserts custom script tags into a site, with the specified values for any dynamic parameters. Call this method when your app is installed on a site.
     *
     * Your app must have an existing
     * [embedded script component](https://dev.wix.com/docs/build-apps/develop-your-app/extensions/site-extensions/embedded-scripts/about-embedded-scripts),
     * with exactly matching parameter names.
     * @param - Details of the script to embed.
     */
    (properties: ScriptProperties, options?: EmbedScriptOptions): Promise<NonNullablePaths<EmbedScriptResponse, {
        [P in ScriptPropertiesNonNullablePaths]: `properties.${P}`;
    }[ScriptPropertiesNonNullablePaths]>>;
}
declare function getEmbeddedScript$1(httpClient: HttpClient): GetEmbeddedScriptSignature;
interface GetEmbeddedScriptSignature {
    /**
     * Retrieves information about your app's existing embedded script.
     *
     * If your app doesn't have an embedded script on the relevant site, a `404` error is returned.
     * @returns Details of the retrieved embedded script.
     */
    (options?: GetEmbeddedScriptOptions): Promise<NonNullablePaths<ScriptProperties, ScriptPropertiesNonNullablePaths>>;
}

declare const embedScript: MaybeContext<BuildRESTFunction<typeof embedScript$1> & typeof embedScript$1>;
declare const getEmbeddedScript: MaybeContext<BuildRESTFunction<typeof getEmbeddedScript$1> & typeof getEmbeddedScript$1>;

export { EmbedScriptOptions, EmbedScriptResponse, GetEmbeddedScriptOptions, ScriptProperties, embedScript, getEmbeddedScript };
