import { NonNullablePaths } from '@wix/sdk-types';

interface ScriptProperties {
    /** Script parameters. */
    parameters?: Record<string, string>;
    /** Whether script is disabled or not. Default: `false` (not disabled). */
    disabled?: boolean;
}
interface EmbedScriptRequest {
    /** Details of the script to embed. */
    properties: ScriptProperties;
    /**
     * Component ID of the embedded script. Available as a query parameter in the embedded script's extension page in the app dashboard.
     * @format GUID
     */
    componentId?: string | null;
}
interface EmbedScriptResponse {
    /** Details of the embedded script. */
    properties?: ScriptProperties;
}
interface GetEmbeddedScriptRequest {
    /**
     * Component ID of the embedded script to retrieve. Available as a query parameter in the embedded script's extension page in the app dashboard.
     * @format GUID
     */
    componentId?: string | null;
}
interface GetEmbeddedScriptResponse {
    /** Details of the retrieved embedded script. */
    properties?: ScriptProperties;
}
interface EmbedScriptByInstanceIdRequest {
    /** @format GUID */
    instanceId?: string;
    /** Parameters to embed */
    properties?: ScriptProperties;
    /** @format GUID */
    componentId?: string | null;
}
interface GetEmbeddedScriptByInstanceIdRequest {
    /** @format GUID */
    instanceId?: string;
    /** @format GUID */
    componentId?: string | null;
}
type ScriptPropertiesNonNullablePaths = `disabled`;
/**
 * Inserts custom script tags into a site, with the specified values for any dynamic parameters. Call this method when your app is installed on a site.
 *
 * Your app must have an existing
 * [embedded script component](https://dev.wix.com/docs/build-apps/develop-your-app/extensions/site-extensions/embedded-scripts/about-embedded-scripts),
 * with exactly matching parameter names.
 * @param properties - Details of the script to embed.
 * @public
 * @requiredField properties
 * @permissionId APPS.MANAGE_EMBEDDED_SCRIPT
 * @applicableIdentity APP
 * @fqn com.wixpress.market.aim.api.EmbeddedScriptsService.EmbedScript
 */
declare function embedScript(properties: ScriptProperties, options?: EmbedScriptOptions): Promise<NonNullablePaths<EmbedScriptResponse, {
    [P in ScriptPropertiesNonNullablePaths]: `properties.${P}`;
}[ScriptPropertiesNonNullablePaths]>>;
interface EmbedScriptOptions {
    /**
     * Component ID of the embedded script. Available as a query parameter in the embedded script's extension page in the app dashboard.
     * @format GUID
     */
    componentId?: string | null;
}
/**
 * Retrieves information about your app's existing embedded script.
 *
 * If your app doesn't have an embedded script on the relevant site, a `404` error is returned.
 * @public
 * @permissionId APPS.MANAGE_EMBEDDED_SCRIPT
 * @applicableIdentity APP
 * @returns Details of the retrieved embedded script.
 * @fqn com.wixpress.market.aim.api.EmbeddedScriptsService.GetEmbeddedScript
 */
declare function getEmbeddedScript(options?: GetEmbeddedScriptOptions): Promise<NonNullablePaths<ScriptProperties, ScriptPropertiesNonNullablePaths>>;
interface GetEmbeddedScriptOptions {
    /**
     * Component ID of the embedded script to retrieve. Available as a query parameter in the embedded script's extension page in the app dashboard.
     * @format GUID
     */
    componentId?: string | null;
}

export { type EmbedScriptByInstanceIdRequest, type EmbedScriptOptions, type EmbedScriptRequest, type EmbedScriptResponse, type GetEmbeddedScriptByInstanceIdRequest, type GetEmbeddedScriptOptions, type GetEmbeddedScriptRequest, type GetEmbeddedScriptResponse, type ScriptProperties, embedScript, getEmbeddedScript };
